{% load i18n %}

<div class="col-md-4 col-sm-6 col-lg-3 col-aa-intel col-aa-intel-dscan-ship-types">
    <header class="aa-intel-section-header my-4">
        <h3 class="aa-intel-section-title">
            {% translate "Ship types" as section_header %}
            {{ section_header|title }}
        </h3>
    </header>

    <div class="card card-default border-0">
        <div class="card-body">
            <div class="table-dscan table-dscan-ship-types table-aa-intel d-none">
                <table class="table table-sm table-sortable table-no-images aa-intel-dscan-ship-types aa-intel-dscan-ship-types-list" style="width: 100%;">
                    <thead>
                    <tr>
                        <th>
                            {% translate "Ship type" as table_header %}
                            {{ table_header|title }}
                        </th>
                        <th>{% translate "Count" %}</th>
                    </tr>
                    </thead>
                </table>
            </div>


            <div class="aa-intel-loading-table-info aa-intel-loading-table-info-ship-types aa-callout aa-callout-info">
                <p>
                    {% translate "Loading data …" %}
                </p>
            </div>

            <div class="aa-intel-empty-table-info aa-intel-empty-table-info-ship-types aa-callout aa-callout-info d-none">
                <p>
                    {% translate "No data." %}
                </p>
            </div>
        </div>
    </div>
</div>
