{% load i18n %}
{% load evelinks %}

{% translate "Unaffiliated / No Alliance" as no_alliance %}

<div class="col-md-6 col-lg-3 aa-intel-chatscan-corporations">
    <header class="aa-intel-section-header my-4">
        <h2 class="aa-intel-section-title">
            {% translate "Corporations breakdown" as table_title %}
            {{ table_title|title }} (<span id="aa-intel-corporations-count">0</span>)
        </h2>
    </header>

    <div class="card card-default border-0">
        <div class="card-body">
            <div class="table-local-scan table-local-scan-corporations table-aa-intel d-none">
                <table class="table table-sm table-sortable aa-intel-corporation-participation-list" style="width: 100%;">
                    <thead>
                        <tr>
                            <th>{% translate "Corporation" %}</th>
                            <th>{% translate "Count" %}</th>
                        </tr>
                    </thead>
                </table>
            </div>

            <div class="aa-intel-loading-table-info aa-intel-loading-table-info-corporation-participation-list aa-callout aa-callout-info">
                <p>
                    {% translate "Loading data …" %}
                </p>
            </div>

            <div class="aa-intel-empty-table-info aa-intel-empty-table-info-corporation-participation-list aa-callout aa-callout-info d-none">
                <p>
                    {% translate "No data …" %}
                </p>
            </div>
        </div>
    </div>
</div>
